==> haskell-one-liner-2.1-237-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-one-liner.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 one-liner
version:              2.1
visibility:           public
id:                   one-liner-2.1-6OEWRZtSndWDtET8r6yk4D
key:                  one-liner-2.1-6OEWRZtSndWDtET8r6yk4D
license:              BSD-3-Clause
maintainer:           sjoerd@w3future.com
author:               Sjoerd Visscher, Xia Li-yao
homepage:             https://github.com/sjoerdvisscher/one-liner
synopsis:             Constraint-based generics
description:
    Write short and concise generic instances of type classes.
    one-liner is particularly useful for writing default
    implementations of type class methods.

category:             Generics
abi:                  2fd962cec4d7614a1c99fdabe83cd24b
exposed:              True
exposed-modules:
    Generics.OneLiner Generics.OneLiner.Binary
    Generics.OneLiner.Classes Generics.OneLiner.Internal
    Generics.OneLiner.Internal.Unary

import-dirs:          /usr/lib/ghc-9.4.8/site-local/one-liner-2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/one-liner-2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/one-liner-2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-one-liner
hs-libraries:         HSone-liner-2.1-6OEWRZtSndWDtET8r6yk4D
depends:
    base-4.17.2.1 bifunctors-5.6.2-GEXn7wFr46IB2mzTOaL0O6
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi ghc-prim-0.9.1
    linear-base-0.5.0-GAortPM1kutBqtYBjZQZOY
    profunctors-5.6.3-5ykNj0b49W3C5puCJKHDiE
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-one-liner/html/one-liner.haddock
haddock-html:         /usr/share/doc/haskell-one-liner/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-one-liner-2.1-238-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-one-liner.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 one-liner
version:              2.1
visibility:           public
id:                   one-liner-2.1-5U15y1Izr8h59jc1mpxKSx
key:                  one-liner-2.1-5U15y1Izr8h59jc1mpxKSx
license:              BSD-3-Clause
maintainer:           sjoerd@w3future.com
author:               Sjoerd Visscher, Xia Li-yao
homepage:             https://github.com/sjoerdvisscher/one-liner
synopsis:             Constraint-based generics
description:
    Write short and concise generic instances of type classes.
    one-liner is particularly useful for writing default
    implementations of type class methods.

category:             Generics
abi:                  c40a9ebd9f2861da41f5939801de7972
exposed:              True
exposed-modules:
    Generics.OneLiner Generics.OneLiner.Binary
    Generics.OneLiner.Classes Generics.OneLiner.Internal
    Generics.OneLiner.Internal.Unary

import-dirs:          /usr/lib/ghc-9.4.8/site-local/one-liner-2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/one-liner-2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/one-liner-2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-one-liner
hs-libraries:         HSone-liner-2.1-5U15y1Izr8h59jc1mpxKSx
depends:
    base-4.17.2.1 bifunctors-5.6.2-8qEFHnQSYft7mo1QPa8LDR
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi ghc-prim-0.9.1
    linear-base-0.5.0-EL7fWbwFVWVJKmx2QwlF6i
    profunctors-5.6.3-KOZLO1xtOlQD6lxDMCq9YO
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-one-liner/html/one-liner.haddock
haddock-html:         /usr/share/doc/haskell-one-liner/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
